Möbelhaus ROLLER

text.skipToContent text.skipToNavigation

# Auftragsauskunft

## Wie funktioniert die online Auftragsauskunft?

Für jede Bestellung erhalten Sie eine Persönliche Identifikations-Nummer (PIN), die wir Ihnen in der Auftragsbestätigung mitteilen. Damit können Sie sich jederzeit über den aktuellen Stand Ihrer Bestellung erkundigen.

In der Auftragsauskunft sehen Sie alle von Ihnen bestellten Artikel, die von Ihnen gewünschte Lieferanschrift, die Zahlungsart, die Versandart und einfach alles, was für Ihre Bestellung von Belang ist. Kontrollieren Sie jederzeit selbst, ob Ihre Zahlung schon verbucht werden konnte und ob die Möbel für Sie am Lager bereit liegen. Sehen Sie auch, welche Spedition Ihnen die Möbel bringen wird und wie Sie selbst Kontakt zum Spediteur aufnehmen können.

Auftragsnummer
Ihre PIN

## Datensicherheit

Selbstverständlich ist nur Ihnen selbst die PIN bekannt. Ausschließlich mit der korrekten Kombination aus Auftragsnummer und zugehöriger PIN kann die Auftragsauskunft eingesehen werden. Alle Daten werden verschlüsselt (128 bit SSL) gesendet.